#undef OPENSSL

#undef GNU_MP

#undef MPI

#undef TOMCRYPT

#undef TOMMATH

#undef CRYPTOLIB

#undef OPENSSL_ENGINE

#undef ENABLE_YP

#undef HIGHFIRST

#undef SHA1HANDSOFF

#undef POSIX_TERMIOS

#undef POSIX_SIGTYPE

#undef PACKAGE

#undef VERSION

#undef volatile
